@@ -3,7 +3,7 @@
  *  Module    : extern.h
  *  Author    : I. Lea
  *  Created   : 1991-04-01
- *  Updated   : 2021-02-25
+ *  Updated   : 2021-07-09
  *  Notes     :
  *
  * Copyright (c) 1997-2021 Iain Lea <iain@bricbrac.de>
@@ -359,7 +359,11 @@
 #	define txt_help_thd_C	txt_help_thd_BIGC
 #endif /* CASE_PROBLEM */
 
-extern char *OPT_CHAR_list[];
+#if defined(MULTIBYTE_ABLE) && !defined(NO_LOCALE)
+	extern wchar_t *OPT_CHAR_list[];
+#else
+	extern char *OPT_CHAR_list[];
+#endif /* MULTIBYTE_ABLE && !NO_LOCALE */
 extern char *OPT_STRING_list[];
 extern char *nntp_server;
 extern char *tin_progname;
@@ -1420,6 +1424,7 @@ extern constext txt_uu_success[];
 extern int *my_group;
 extern int NOTESLINES;
 extern int _hp_glitch;
+extern int art_mark_width;
 extern int attrib_file_offset;
 extern int cCOLS;
 extern int cLINES;
@@ -1566,7 +1571,6 @@ enum {
 	HIST_SHELL_COMMAND,
 	HIST_SUBJECT_SEARCH,
 	HIST_CONFIG_SEARCH,
-	HIST_HELP_SEARCH,
 	HIST_URL
 };
 /* must always be the same as the highest HIST_ value except HIST_NONE */
@@ -1833,7 +1837,6 @@ extern struct opttxt txt_sort_article_type;
 extern struct opttxt txt_sort_threads_type;
 extern struct opttxt txt_spamtrap_warning_addresses;
 extern struct opttxt txt_stars_regex;
-extern struct opttxt txt_start_editor_offset;
 #ifndef USE_CURSES
 	extern struct opttxt txt_strip_blanks;
 #endif /* !USE_CURSES */
