@@ -3,7 +3,7 @@
  *  Module    : config.c
  *  Author    : I. Lea
  *  Created   : 1991-04-01
- *  Updated   : 2021-02-23
+ *  Updated   : 2021-08-05
  *  Notes     : Configuration file routines
  *
  * Copyright (c) 1991-2021 Iain Lea <iain@bricbrac.de>
@@ -63,8 +63,26 @@ static void write_server_config(void);
 #endif /* HAVE_COLOR */
 
 
-#define DASH_TO_SPACE(mark)	((char) (mark == '_' ? ' ' : mark))
-#define SPACE_TO_DASH(mark)	((char) (mark == ' ' ? '_' : mark))
+#if defined(MULTIBYTE_ABLE) && !defined(NO_LOCALE)
+#	define DASH_TO_SPACE(mark)	((wchar_t) (mark == L'_' ? L' ' : mark))
+#	define SPACE_TO_DASH(mark)	((wchar_t) (mark == L' ' ? L'_' : mark))
+#	define SET_RC_VAL(buf, rcval, defval) do { \
+		wchar_t *wbuf; \
+		if ((wbuf = char2wchar_t(buf))) { \
+			wbuf[1] = (wchar_t) '\0'; \
+			rcval = !wbuf[0] ? (wchar_t) defval : DASH_TO_SPACE(wbuf[0]); \
+			if (art_mark_width < wcswidth(wbuf, 1)) \
+				art_mark_width = wcswidth(wbuf, 1); \
+			free(wbuf); \
+		} \
+	} while (0)
+#else
+#	define DASH_TO_SPACE(mark)	((char) (mark == '_' ? ' ' : mark))
+#	define SPACE_TO_DASH(mark)	((char) (mark == ' ' ? '_' : mark))
+#	define SET_RC_VAL(buf, rcval, defval) do { \
+		rcval = !buf[0] ? defval : DASH_TO_SPACE(buf[0]); \
+	} while (0)
+#endif /* MULTIBYTE_ABLE && !NO_LOCALE */
 
 
 /*
@@ -96,7 +114,7 @@ read_config_file(
 			if (upgrade == NULL && !global_file && match_string(buf, "# tin configuration file V", NULL, 0)) {
 				upgrade = check_upgrade(buf, "# tin configuration file V", TINRC_VERSION);
 				if (upgrade->state != RC_IGNORE)
-					upgrade_prompt_quit(upgrade, CONFIG_FILE);
+					upgrade_prompt_quit(upgrade, file); /* CONFIG_FILE */
 				if (upgrade->state == RC_UPGRADE)
 					rc_update(fp);
 			}
@@ -118,47 +136,47 @@ read_config_file(
 				break;
 
 			if (match_string(buf, "art_marked_deleted=", tmp, sizeof(tmp))) {
-				tinrc.art_marked_deleted = !tmp[0] ? ART_MARK_DELETED : DASH_TO_SPACE(tmp[0]);
+				SET_RC_VAL(tmp, tinrc.art_marked_deleted, ART_MARK_DELETED);
 				break;
 			}
 
 			if (match_string(buf, "art_marked_inrange=", tmp, sizeof(tmp))) {
-				tinrc.art_marked_inrange = !tmp[0] ? MARK_INRANGE : DASH_TO_SPACE(tmp[0]);
+				SET_RC_VAL(tmp, tinrc.art_marked_inrange, MARK_INRANGE);
 				break;
 			}
 
 			if (match_string(buf, "art_marked_killed=", tmp, sizeof(tmp))) {
-				tinrc.art_marked_killed = !tmp[0] ? ART_MARK_KILLED : DASH_TO_SPACE(tmp[0]);
+				SET_RC_VAL(tmp, tinrc.art_marked_killed, ART_MARK_KILLED);
 				break;
 			}
 
 			if (match_string(buf, "art_marked_read=", tmp, sizeof(tmp))) {
-				tinrc.art_marked_read = !tmp[0] ? ART_MARK_READ : DASH_TO_SPACE(tmp[0]);
+				SET_RC_VAL(tmp, tinrc.art_marked_read, ART_MARK_READ);
 				break;
 			}
 
 			if (match_string(buf, "art_marked_read_selected=", tmp, sizeof(tmp))) {
-				tinrc.art_marked_read_selected = !tmp[0] ? ART_MARK_READ_SELECTED : DASH_TO_SPACE(tmp[0]);
+				SET_RC_VAL(tmp, tinrc.art_marked_read_selected, ART_MARK_READ_SELECTED);
 				break;
 			}
 
 			if (match_string(buf, "art_marked_recent=", tmp, sizeof(tmp))) {
-				tinrc.art_marked_recent = !tmp[0] ? ART_MARK_RECENT : DASH_TO_SPACE(tmp[0]);
+				SET_RC_VAL(tmp, tinrc.art_marked_recent, ART_MARK_RECENT);
 				break;
 			}
 
 			if (match_string(buf, "art_marked_return=", tmp, sizeof(tmp))) {
-				tinrc.art_marked_return = !tmp[0] ? ART_MARK_RETURN : DASH_TO_SPACE(tmp[0]);
+				SET_RC_VAL(tmp, tinrc.art_marked_return, ART_MARK_RETURN);
 				break;
 			}
 
 			if (match_string(buf, "art_marked_selected=", tmp, sizeof(tmp))) {
-				tinrc.art_marked_selected = !tmp[0] ? ART_MARK_SELECTED : DASH_TO_SPACE(tmp[0]);
+				SET_RC_VAL(tmp, tinrc.art_marked_selected, ART_MARK_SELECTED);
 				break;
 			}
 
 			if (match_string(buf, "art_marked_unread=", tmp, sizeof(tmp))) {
-				tinrc.art_marked_unread = !tmp[0] ? ART_MARK_UNREAD : DASH_TO_SPACE(tmp[0]);
+				SET_RC_VAL(tmp, tinrc.art_marked_unread, ART_MARK_UNREAD);
 				break;
 			}
 
@@ -686,9 +704,6 @@ read_config_file(
 			if (match_string(buf, "spamtrap_warning_addresses=", tinrc.spamtrap_warning_addresses, sizeof(tinrc.spamtrap_warning_addresses)))
 				break;
 
-			if (match_boolean(buf, "start_editor_offset=", &tinrc.start_editor_offset))
-				break;
-
 			if (match_integer(buf, "sort_article_type=", &tinrc.sort_article_type, SORT_ARTICLES_BY_LINES_ASCEND))
 				break;
 
@@ -893,7 +908,7 @@ read_config_file(
 
 	/* set defaults if blank */
 	if (!*tinrc.editor_format)
-		STRCPY(tinrc.editor_format, TIN_EDITOR_FMT_ON);
+		STRCPY(tinrc.editor_format, TIN_EDITOR_FMT);
 	if (!*tinrc.select_format)
 		STRCPY(tinrc.select_format, DEFAULT_SELECT_FORMAT);
 	if (!*tinrc.group_format)
@@ -1044,9 +1059,6 @@ write_config_file(
 	fprintf(fp, "%s", _(txt_batch_save.tinrc));
 	fprintf(fp, "batch_save=%s\n\n", print_boolean(tinrc.batch_save));
 
-	fprintf(fp, "%s", _(txt_start_editor_offset.tinrc));
-	fprintf(fp, "start_editor_offset=%s\n\n", print_boolean(tinrc.start_editor_offset));
-
 	fprintf(fp, "%s", _(txt_editor_format.tinrc));
 	fprintf(fp, "editor_format=%s\n\n", tinrc.editor_format);
 
@@ -1159,31 +1171,31 @@ write_config_file(
 #endif /* MULTIBYTE_ABLE && !NO_LOCALE */
 
 	fprintf(fp, "%s", _(txt_art_marked_deleted.tinrc));
-	fprintf(fp, "art_marked_deleted=%c\n\n", SPACE_TO_DASH(tinrc.art_marked_deleted));
+	fprintf(fp, "art_marked_deleted=%"T_CHAR_FMT"\n\n", SPACE_TO_DASH(tinrc.art_marked_deleted));
 
 	fprintf(fp, "%s", _(txt_art_marked_inrange.tinrc));
-	fprintf(fp, "art_marked_inrange=%c\n\n", SPACE_TO_DASH(tinrc.art_marked_inrange));
+	fprintf(fp, "art_marked_inrange=%"T_CHAR_FMT"\n\n", SPACE_TO_DASH(tinrc.art_marked_inrange));
 
 	fprintf(fp, "%s", _(txt_art_marked_return.tinrc));
-	fprintf(fp, "art_marked_return=%c\n\n", SPACE_TO_DASH(tinrc.art_marked_return));
+	fprintf(fp, "art_marked_return=%"T_CHAR_FMT"\n\n", SPACE_TO_DASH(tinrc.art_marked_return));
 
 	fprintf(fp, "%s", _(txt_art_marked_selected.tinrc));
-	fprintf(fp, "art_marked_selected=%c\n\n", SPACE_TO_DASH(tinrc.art_marked_selected));
+	fprintf(fp, "art_marked_selected=%"T_CHAR_FMT"\n\n", SPACE_TO_DASH(tinrc.art_marked_selected));
 
 	fprintf(fp, "%s", _(txt_art_marked_recent.tinrc));
-	fprintf(fp, "art_marked_recent=%c\n\n", SPACE_TO_DASH(tinrc.art_marked_recent));
+	fprintf(fp, "art_marked_recent=%"T_CHAR_FMT"\n\n", SPACE_TO_DASH(tinrc.art_marked_recent));
 
 	fprintf(fp, "%s", _(txt_art_marked_unread.tinrc));
-	fprintf(fp, "art_marked_unread=%c\n\n", SPACE_TO_DASH(tinrc.art_marked_unread));
+	fprintf(fp, "art_marked_unread=%"T_CHAR_FMT"\n\n", SPACE_TO_DASH(tinrc.art_marked_unread));
 
 	fprintf(fp, "%s", _(txt_art_marked_read.tinrc));
-	fprintf(fp, "art_marked_read=%c\n\n", SPACE_TO_DASH(tinrc.art_marked_read));
+	fprintf(fp, "art_marked_read=%"T_CHAR_FMT"\n\n", SPACE_TO_DASH(tinrc.art_marked_read));
 
 	fprintf(fp, "%s", _(txt_art_marked_killed.tinrc));
-	fprintf(fp, "art_marked_killed=%c\n\n", SPACE_TO_DASH(tinrc.art_marked_killed));
+	fprintf(fp, "art_marked_killed=%"T_CHAR_FMT"\n\n", SPACE_TO_DASH(tinrc.art_marked_killed));
 
 	fprintf(fp, "%s", _(txt_art_marked_read_selected.tinrc));
-	fprintf(fp, "art_marked_read_selected=%c\n\n", SPACE_TO_DASH(tinrc.art_marked_read_selected));
+	fprintf(fp, "art_marked_read_selected=%"T_CHAR_FMT"\n\n", SPACE_TO_DASH(tinrc.art_marked_read_selected));
 
 	fprintf(fp, "%s", _(txt_force_screen_redraw.tinrc));
 	fprintf(fp, "force_screen_redraw=%s\n\n", print_boolean(tinrc.force_screen_redraw));
